<TS language="ku_IQ" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>ناوونیشانێکی نوێ دروست بکە</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;نوێ</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>کۆپیکردنی ناونیشانی هەڵبژێردراوی ئێستا بۆ کلیپ بۆردی سیستەم</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;ڕوونووس</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;داخستن</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>سڕینەوەی ناونیشانی هەڵبژێردراوی ئێستا لە لیستەکە</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>ناونیشانێک بنووسە یان پێناسەیەک داخڵ بکە بۆ گەڕان</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ناردنی داتا لە خشتەبەندی ئێستا بۆ فایلێک</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;هەناردن</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;سڕینەوە</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>ناونیشانەکە هەڵبژێرە بۆ ناردنی دراوەکان بۆ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>ناونیشانەکە هەڵبژێرە بۆ وەرگرتنی دراوەکان لەگەڵ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;هەڵبژێرە</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>ناردنی ناونیشانەکان</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>وەرگرتنی ناونیشانەکان</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>ئەمانە ناونیشانی بیتکۆبیتەکانی تۆنە بۆ ناردنی پارەدانەکان. هەمیشە بڕی و ناونیشانی وەرگرەکان بپشکنە پێش ناردنی دراوەکان.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;ڕوونووسکردن ناوونیشان</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>کۆپی &amp;ناونیشان</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;دەسکاریکردن</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>لیستی ناونیشان هاوردە بکە</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>فایلی جیاکراوە بە کۆما (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>هەناردەکردن سەرکەوتوو نەبوو</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>هەڵەیەک ڕوویدا لە هەوڵی خەزنکردنی لیستی ناونیشانەکە بۆ %1. تکایە دووبارە هەوڵ دەوە.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>پێناسەکردن</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>ناوونیشان</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(بێ ناونیشان)

</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>دیالۆگی دەستەواژەی تێپەڕبوون</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>دەستەواژەی تێپەڕبوون بنووسە</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>دەستەواژەی تێپەڕی نوێ</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>دووبارەکردنەوەی دەستەواژەی تێپەڕی نوێ</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>دەستەواژەی تێپەڕەوی نوێ تێبنووسە بۆ جزدان.1 تکایە دەستەواژەی تێپەڕێک بەکاربێنە لە 2ten یان زیاتر لە هێما هەڕەمەکیەکان2، یان 38 یان زیاتر ووشەکان3.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>بیرت بێت کە ڕەمزاندنی جزدانەکەت ناتوانێت بەتەواوی بیتکۆبیتەکانت بپارێزێت لە دزرابوون لەلایەن وورنەری تووشکردنی کۆمپیوتەرەکەت.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>گرنگ: هەر پاڵپشتێکی پێشووت دروست کردووە لە فایلی جزدانەکەت دەبێت جێگۆڕکێی پێ بکرێت لەگەڵ فایلی جزدانی نهێنی تازە دروستکراو. لەبەر هۆکاری پاراستن، پاڵپشتەکانی پێشووی فایلی جزدانێکی نهێنی نەکراو بێ سوود دەبن هەر کە دەستت کرد بە بەکارهێنانی جزدانی نوێی کۆدکراو.</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Options...</source>
        <translation type="unfinished">&amp;هەڵبژاردنەکان...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;ناردن</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;پەرگە</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;سازکارییەکان</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;یارمەتی</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>ئاگاداری</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>زانیاری</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;ناردنی ناونیشانەکان</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;وەرگرتنی ناونیشانەکان</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>کۆ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>تێچوون:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>سەرجەم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Copy amount</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;ڕوونووسکردن ناوونیشان</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Copy label</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Copy amount</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Copy transaction ID</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>بەڵێ</translation>
    </message>
    <message>
        <source>no</source>
        <translation>نەخێر</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(بێ ناونیشان)

</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;پێناسەکردن</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;ناوونیشان</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation>ناونیشان "%1" پێشتر هەبوو وەک ناونیشانی وەرگرتن لەگەڵ ناونیشانی "%2" و بۆیە ناتوانرێت زیاد بکرێت وەک ناونیشانی ناردن.</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>ناو</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>دایەرێکتۆری پێش ئێستا هەیە. %1 زیاد بکە ئەگەر بەتەما بیت لێرە ڕێنیشاندەرێکی نوێ دروست بکەیت.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>ناتوانیت لێرە داتا دروست بکەیت.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>وەشان</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>بەخێربێن</translation>
    </message>
    <message>
        <source>When you click OK, %1 will begin to download and process the full %4 block chain (%2GB) starting with the earliest transactions in %3 when %4 initially launched.</source>
        <translation>کاتێک کرتە لە پەسەندە دەکەیت، %1 دەست دەکات بە داگرتن و پرۆسەی زنجیرەبلۆکی %4 (%2GB) بە سەرەتاییترین مامەڵەکان لە %3 دەست پێدەکات کاتێک %4 لە سەرەتادا دەستی پێکرد.</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain. It is faster to download the full chain first and prune it later. Disables some advanced features.</source>
        <translation>دووبارە کردنەوەی ئەم ڕێکخستنە پێویستی بە دووبارە داگرتنی تەواوی بەربەستەکە هەیە. خێراترە بۆ داگرتنی زنجیرەی تەواو سەرەتا و داگرتنی دواتر. هەندێک تایبەتمەندی پێشکەوتوو لە کار دەهێنێت.</translation>
    </message>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation>ئەم هاوکاتکردنە سەرەتاییە زۆر داوای دەکات، و لەوانەیە کێشەکانی رەقەواڵە لەگەڵ کۆمپیوتەرەکەت دابخات کە پێشتر تێبینی نەکراو بوو. هەر جارێک کە %1 رادەدەیت، بەردەوام دەبێت لە داگرتن لەو شوێنەی کە بەجێی هێشت.</translation>
    </message>
    <message>
        <source>If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low.</source>
        <translation>ئەگەر تۆ دیاریت کردووە بۆ سنووردارکردنی کۆگە زنجیرەی بلۆک (کێڵکردن)، هێشتا داتای مێژووی دەبێت دابەزێنرێت و پرۆسەی بۆ بکرێت، بەڵام دواتر دەسڕدرێتەوە بۆ ئەوەی بەکارهێنانی دیسکەکەت کەم بێت.</translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Bitcoin block chain.</source>
        <translation>%1 کۆپیەکی زنجیرەی بلۆکی بیتکۆپ دائەبەزێنێت و خەزنی دەکات.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>%1 is currently syncing.  It will download headers and blocks from peers and validate them until reaching the tip of the block chain.</source>
        <translation>%1 لە ئێستادا هاوکات دەکرێت.  سەرپەڕ و بلۆکەکان لە هاوتەمەنەکان دابەزێنێت و کارایان دەکات تا گەیشتن بە سەرەی زنجیرەی بلۆک.</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>جۆر</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>ناوونیشان</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>هەڵبژاردنەکان</translation>
    </message>
    <message>
        <source>Third party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation>یو ئێڕ ئێڵەکانی لایەنی سێیەم. (بۆ وێنە گەڕاڵی بلۆک) کە لە تابی مامەڵەکان وەک بڕگەکان پێرستی دەق دەردەکەوێت. %s لە URL دا جێگەی دەگۆڕدرێتەوە بە هاش.. چەندین URL جیاکراونەتەوە بە شریتی ستوونی |.</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;تۆڕ</translation>
    </message>
    <message>
        <source>Disables some advanced features but all blocks will still be fully validated. Reverting this setting requires re-downloading the entire blockchain. Actual disk usage may be somewhat higher.</source>
        <translation>هەندێک تایبەتمەندی پێشکەوتوو لە کاربخە بەڵام هەموو بلۆکەکان هێشتا بە تەواوی ساغ دەکرانەوە. دووبارە کردنەوەی ئەم ڕێکخستنە پێویستی بە دووبارە داگرتنی تەواوی بەربەستەکە هەیە. بەکارهێنانی ڕاستەقینەی دیسک لەوانەیە تا رادەیەک زیاتر بێت.</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation>دووبارە کردنەوەی ئەم ڕێکخستنە پێویستی بە دووبارە داگرتنی تەواوی بەربەستەکە هەیە.</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>ڕووکاری بەکارهێنەر &amp;زمان:</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting %1.</source>
        <translation>زمانی ڕووکاری بەکارهێنەر دەکرێت لێرە دابنرێت. ئەم ڕێکخستنە کاریگەر دەبێت پاش دەستپێکردنەوەی %1.</translation>
    </message>
    <message>
        <source>The configuration file is used to specify advanced user options which override GUI settings. Additionally, any command-line options will override this configuration file.</source>
        <translation>فایلی شێوەپێدان بەکاردێت بۆ دیاریکردنی هەڵبژاردنەکانی بەکارهێنەری پێشکەوتوو کە زیادەڕەوی لە ڕێکخستنەکانی GUI دەکات. لەگەڵ ئەوەش، هەر بژاردەکانی هێڵی فەرمان زیادەڕەوی دەکات لە سەر ئەم فایلە شێوەپێدانە.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Total:</source>
        <translation>گشتی</translation>
    </message>
    <message>
        <source>Privacy mode activated for the Overview tab. To unmask the values, uncheck Settings-&gt;Mask values.</source>
        <translation>دۆخی تایبەتمەندی چالاک کرا بۆ تابی گشتی. بۆ کردنەوەی بەهاکان، بەهاکان ڕێکخستنەکان&gt;ماسک.</translation>
    </message>
</context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Cداخستن</translation>
    </message>
    <message>
        <source>or</source>
        <translation>یان</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation>ناتوانێت دەست بکات بە bitcoin: کرتە بکە بۆ-پارەدانی کار</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Sent</source>
        <translation>نێدرا</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>جۆر</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>سەرجەم</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>ئەنجامی URL زۆر درێژە، هەوڵ بدە دەقەکە کەم بکەیتەوە بۆ پێناسە / نامە.</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;زانیاری</translation>
    </message>
    <message>
        <source>General</source>
        <translation>گشتی</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>تۆڕ</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>ناو</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>نێدرا</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>وەشان</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>خزمەتگوزاریەکان</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;کردنەوە</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>لە ناو</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>لەدەرەوە</translation>
    </message>
    <message>
        <source>1 &amp;hour</source>
        <translation>1&amp;سات</translation>
    </message>
    <message>
        <source>1 &amp;week</source>
        <translation>1&amp;هەفتە</translation>
    </message>
    <message>
        <source>1 &amp;year</source>
        <translation>1&amp;ساڵ</translation>
    </message>
    <message>
        <source>To</source>
        <translation>بۆ</translation>
    </message>
    <message>
        <source>From</source>
        <translation>لە</translation>
    </message>
    <message>
        <source>No</source>
        <translation>نەخێر</translation>
    </message>
    <message>
        <source>1 d&amp;ay</source>
        <translation type="unfinished">1&amp;ڕۆژ</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;ڕوونووسکردن ناوونیشان</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;سەرجەم:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;پێناسەکردن:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;پەیام:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>پاککردنەوە</translation>
    </message>
    <message>
        <source>Show the selected request (does the same as double clicking an entry)</source>
        <translation>پیشاندانی داواکارییە دیاریکراوەکان (هەمان کرتەی دووانی کرتەکردن دەکات لە تۆمارێک)</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>پیشاندان</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>سڕینەوە</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;ڕوونووسکردن ناوونیشان</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Copy label</translation>
    </message>
    <message>
        <source>Copy &amp;message</source>
        <translation type="unfinished">&amp;Copy message</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Copy amount</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">ناوونیشان:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>کۆ:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">پێناسەکردن:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>پەیام:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;ڕوونووسکردن ناوونیشان</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>پێناسەکردن</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>پەیام</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(بێ ناونیشان)

</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>کۆ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>تێچوون:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">هەڵبژێرە...</translation>
    </message>
    <message>
        <source>Hide transaction fee settings</source>
        <translation>شاردنەوەی ڕێکخستنەکانی باجی مامەڵە</translation>
    </message>
    <message>
        <source>When there is less transaction volume than space in the blocks, miners as well as relaying nodes may enforce a minimum fee. Paying only this minimum fee is just fine, but be aware that this can result in a never confirming transaction once there is more demand for bitcoin transactions than the network can process.</source>
        <translation>کاتێک قەبارەی مامەڵە کەمتر بێت لە بۆشایی بلۆکەکان، لەوانەیە کانەکان و گرێکانی گواستنەوە کەمترین کرێ جێبەجێ بکەن. پێدانی تەنیا ئەم کەمترین کرێیە تەنیا باشە، بەڵام ئاگاداربە کە ئەمە دەتوانێت ببێتە هۆی ئەوەی کە هەرگیز مامەڵەیەکی پشتڕاستکردنەوە ئەنجام بدرێت جارێک داواکاری زیاتر هەیە بۆ مامەڵەکانی بیت کۆبیتکۆ لەوەی کە تۆڕەکە دەتوانێت ئەنجامی بدات.</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;ناردن</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Copy amount</translation>
    </message>
    <message>
        <source>or</source>
        <translation>یان</translation>
    </message>
    <message>
        <source>Please, review your transaction proposal. This will produce a Partially Signed Bitcoin Transaction (PSBT) which you can save or copy and then sign with e.g. an offline %1 wallet, or a PSBT-compatible hardware wallet.</source>
        <translation>تکایە، پێداچوونەوە بکە بە پێشنیارەکانی مامەڵەکەت. ئەمە مامەڵەیەکی بیتکۆپەکی کەبەشیونکراو (PSBT) بەرهەمدەهێنێت کە دەتوانیت پاشەکەوتی بکەیت یان کۆپی بکەیت و پاشان واژووی بکەیت لەگەڵ بۆ ئەوەی بە دەرهێڵی %1 جزدانێک، یان جزدانێکی رەقەواڵەی گونجاو بە PSBT.</translation>
    </message>
    <message>
        <source>Please, review your transaction.</source>
        <translation>تکایە، چاو بە مامەڵەکەتدا بخشێنەوە.</translation>
    </message>
    <message>
        <source>To review recipient list click "Show Details..."</source>
        <translation>بۆ پێداچوونەوەی لیستی وەرگرتن کرتە بکە لەسەر "پیشاندانی وردەکاریەکان..."</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">ناردن</translation>
    </message>
    <message>
        <source>The recipient address is not valid. Please recheck.</source>
        <translation>ناونیشانی وەرگرتنەکە دروست نییە. تکایە دووبارە پشکنین بکەوە.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(بێ ناونیشان)

</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;سەرجەم:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;پێناسەکردن:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>پەیام:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Enter the receiver's address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack. Note that this only proves the signing party receives with the address, it cannot prove sendership of any transaction!</source>
        <translation>ناونیشانی وەرگرەکە بنووسە، نامە (دڵنیابە لەوەی کە جیاکەرەوەکانی هێڵ، مەوداکان، تابەکان، و هتد بە تەواوی کۆپی بکە) و لە خوارەوە واژووی بکە بۆ سەلماندنی نامەکە. وریابە لەوەی کە زیاتر نەیخوێنیتەوە بۆ ناو واژووەکە لەوەی کە لە خودی پەیامە واژووەکەدایە، بۆ ئەوەی خۆت بەدوور بگریت لە فێڵکردن لە هێرشی پیاوان لە ناوەنددا. سەرنج بدە کە ئەمە تەنیا لایەنی واژووکردن بە ناونیشانەکە وەربگرە، ناتوانێت نێرەری هیچ مامەڵەیەک بسەلمێنێت!</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>کرتە بکە لەسەر "نامەی واژوو" بۆ دروستکردنی واژوو</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>تکایە ناونیشانەکە بپشکنە و دووبارە هەوڵ دەوە.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>تکایە واژووەکە بپشکنە و دووبارە هەوڵ دەوە.</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Status</source>
        <translation>بارودۆخ</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>سەرچاوە</translation>
    </message>
    <message>
        <source>From</source>
        <translation>لە</translation>
    </message>
    <message>
        <source>To</source>
        <translation>بۆ</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>پەیام</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>سەرجەم</translation>
    </message>
    <message>
        <source>true</source>
        <translation>دروستە</translation>
    </message>
    <message>
        <source>false</source>
        <translation>نادروستە</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>جۆر</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>پێناسەکردن</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>ناردن بۆ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(بێ ناونیشان)

</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Sent to</source>
        <translation>ناردن بۆ</translation>
    </message>
    <message>
        <source>Enter address, transaction id, or label to search</source>
        <translation>ناونیشانێک بنووسە، ناسنامەی مامەڵە، یان ناولێنانێک بۆ گەڕان بنووسە</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;ڕوونووسکردن ناوونیشان</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Copy label</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Copy amount</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Copy transaction ID</translation>
    </message>
    <message>
        <source>Copy &amp;raw transaction</source>
        <translation type="unfinished">&amp;Copy raw transaction</translation>
    </message>
    <message>
        <source>Copy full transaction &amp;details</source>
        <translation type="unfinished">&amp;Copy full transaction details</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>فایلی جیاکراوە بە کۆما (*.csv)</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>جۆر</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>پێناسەکردن</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>ناوونیشان</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>هەناردەکردن سەرکەوتوو نەبوو</translation>
    </message>
    <message>
        <source>to</source>
        <translation>بۆ</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation>یەکە بۆ نیشاندانی بڕی کرتە بکە بۆ دیاریکردنی یەکەیەکی تر.</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;هەناردن</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>ناردنی داتا لە خشتەبەندی ئێستا بۆ فایلێک</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Prune configured below the minimum of %d MiB.  Please use a higher number.</source>
        <translation>پڕە لە خوارەوەی کەمترین %d MiB شێوەبەند کراوە.  تکایە ژمارەیەکی بەرزتر بەکاربێنە.</translation>
    </message>
    <message>
        <source>Prune: last wallet synchronisation goes beyond pruned data. You need to -reindex (download the whole blockchain again in case of pruned node)</source>
        <translation>پرە: دوایین هاودەمکردنی جزدان لە داتای بەپێز دەچێت. پێویستە دووبارە -ئیندێکس بکەیتەوە (هەموو بەربەستەکە دابەزێنە دووبارە لە حاڵەتی گرێی هەڵکراو)</translation>
    </message>
    <message>
        <source>Cannot provide specific connections and have addrman find outgoing connections at the same.</source>
        <translation>ناتوانێت گرێدانێکی تایبەت دابین بکات و پەیوەندی دەرکەوی هەبێت لە هەمان کاتدا.</translation>
    </message>
    <message>
        <source>Please check that your computer's date and time are correct! If your clock is wrong, %s will not work properly.</source>
        <translation>تکایە بپشکنە کە بەروار و کاتی کۆمپیوتەرەکەت ڕاستە! ئەگەر کاژێرەکەت هەڵە بوو، %s بە دروستی کار ناکات.</translation>
    </message>
    <message>
        <source>Please contribute if you find %s useful. Visit %s for further information about the software.</source>
        <translation>تکایە بەشداری بکە ئەگەر %s بەسوودت دۆزیەوە. سەردانی %s بکە بۆ زانیاری زیاتر دەربارەی نەرمواڵەکە.</translation>
    </message>
    <message>
        <source>Unable to rewind the database to a pre-fork state. You will need to redownload the blockchain</source>
        <translation>ناتوانێت داتابەیس بۆ دۆخی پێشوەختە هەڵبووەشێتەوە. تۆ پێویستە زنجیرە بلۆکەکە دابگریتەوە</translation>
    </message>
    <message>
        <source>Copyright (C) %i-%i</source>
        <translation>مافی چاپ (C) %i-%i</translation>
    </message>
    <message>
        <source>Could not find asmap file %s</source>
        <translation>ئاسماپ بدۆزرێتەوە %s نەتوانرا فایلی</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
    <message>
        <source>This error could occur if this wallet was not shutdown cleanly and was last loaded using a build with a newer version of Berkeley DB. If so, please use the software that last loaded this wallet</source>
        <translation>ئەم هەڵەیە لەوانەیە ڕووبدات ئەگەر ئەم جزدانە بە خاوێنی دانەبەزێنرابێت و دواجار بارکرا بێت بە بەکارهێنانی بنیاتێک بە وەشانێکی نوێتری بێرکلی DB. ئەگەر وایە، تکایە ئەو سۆفتوێرە بەکاربهێنە کە دواجار ئەم جزدانە بارکرا بوو</translation>
    </message>
    <message>
        <source>Transaction needs a change address, but we can't generate it. Please call keypoolrefill first.</source>
        <translation>مامەڵە پێویستی بە ناونیشانی گۆڕینە، بەڵام ناتوانین دروستی بکەین. تکایە سەرەتا پەیوەندی بکە بە پڕکردنەوەی کلیلەکە.</translation>
    </message>
    <message>
        <source>You need to rebuild the database using -reindex to go back to unpruned mode.  This will redownload the entire blockchain</source>
        <translation>پێویستە بنکەی زانیارییەکان دروست بکەیتەوە بە بەکارهێنانی -دووبارە ئیندێکس بۆ گەڕانەوە بۆ دۆخی نەپڕاو.  ئەمە هەموو بەربەستەکە دائەبەزێنێت</translation>
    </message>
    <message>
        <source>Error: Keypool ran out, please call keypoolrefill first</source>
        <translation>هەڵە: کلیلی پوول ڕایکرد، تکایە سەرەتا پەیوەندی بکە بە پڕکردنەوەی کلیل</translation>
    </message>
    </context>
</TS>